# Rezbuild

Rezbuild is a Python library for build rez packages. Please look 
[Rez](https://github.com/nerdvegas/rez) for more information about rez.

## Author
[PiliPala](https://gitlab.com/Pili-Pala)

## Getting Started

### requisites

### Installing

## Running the tests

### Break down into end to end tests

### And coding style tests

## Usage

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available,
see the [tags on this repository](https://gitlab.com/Pili-Pala/rezbuild/tags).

## License
[GPLv3](https://www.gnu.org/licenses/gpl-3.0.txt)
